[llvm-commits] [llvm] r79981 - in /llvm/trunk/lib/CodeGen/AsmPrinter: DwarfException.cpp DwarfException.h

Bill Wendling isanbard at gmail.com
Tue Aug 25 01:08:35 PDT 2009


Author: void
Date: Tue Aug 25 03:08:33 2009
New Revision: 79981

URL: http://llvm.org/viewvc/llvm-project?rev=79981&view=rev
Log:
- Rename EmitCommonInformationEntry to EmitCIE.
- Rename EmitFunctionDescriptionEntry to EmitFDE.

Modified:
    llvm/trunk/lib/CodeGen/AsmPrinter/DwarfException.cpp
    llvm/trunk/lib/CodeGen/AsmPrinter/DwarfException.h

Modified: llvm/trunk/lib/CodeGen/AsmPrinter/DwarfException.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/AsmPrinter/DwarfException.cpp?rev=79981&r1=79980&r2=79981&view=diff

==============================================================================
--- llvm/trunk/lib/CodeGen/AsmPrinter/DwarfException.cpp (original)
+++ llvm/trunk/lib/CodeGen/AsmPrinter/DwarfException.cpp Tue Aug 25 03:08:33 2009
@@ -49,11 +49,10 @@
   delete ExceptionTimer;
 }
 
-/// EmitCommonInformationEntry - Emit a Common Information Entry (CIE). This
-/// holds information that is shared among many Frame Description Entries.
-/// There is at least one CIE in every non-empty .debug_frame section.
-void DwarfException::EmitCommonInformationEntry(const Function *Personality,
-                                                unsigned Index) {
+/// EmitCIE - Emit a Common Information Entry (CIE). This holds information that
+/// is shared among many Frame Description Entries.  There is at least one CIE
+/// in every non-empty .debug_frame section.
+void DwarfException::EmitCIE(const Function *Personality, unsigned Index) {
   // Size and sign of stack growth.
   int stackGrowth =
     Asm->TM.getFrameInfo()->getStackGrowthDirection() ==
@@ -147,10 +146,8 @@
   Asm->EOL();
 }
 
-/// EmitFrameDescriptionEntry - Emit the Frame Description Entry (FDE) for the
-/// function.
-void DwarfException::
-EmitFrameDescriptionEntry(const FunctionEHFrameInfo &EHFrameInfo) {
+/// EmitFDE - Emit the Frame Description Entry (FDE) for the function.
+void DwarfException::EmitFDE(const FunctionEHFrameInfo &EHFrameInfo) {
   assert(!EHFrameInfo.function->hasAvailableExternallyLinkage() && 
          "Should not emit 'available externally' functions at all");
 
@@ -850,11 +847,11 @@
   if (shouldEmitMovesModule || shouldEmitTableModule) {
     const std::vector<Function *> Personalities = MMI->getPersonalities();
     for (unsigned i = 0; i < Personalities.size(); ++i)
-      EmitCommonInformationEntry(Personalities[i], i);
+      EmitCIE(Personalities[i], i);
 
     for (std::vector<FunctionEHFrameInfo>::iterator I = EHFrames.begin(),
            E = EHFrames.end(); I != E; ++I)
-      EmitFrameDescriptionEntry(*I);
+      EmitFDE(*I);
   }
 
   if (TimePassesIsEnabled)

Modified: llvm/trunk/lib/CodeGen/AsmPrinter/DwarfException.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/AsmPrinter/DwarfException.h?rev=79981&r1=79980&r2=79981&view=diff

==============================================================================
--- llvm/trunk/lib/CodeGen/AsmPrinter/DwarfException.h (original)
+++ llvm/trunk/lib/CodeGen/AsmPrinter/DwarfException.h Tue Aug 25 03:08:33 2009
@@ -70,14 +70,13 @@
   /// ExceptionTimer - Timer for the Dwarf exception writer.
   Timer *ExceptionTimer;
 
-  /// EmitCommonInformationEntry - Emit a Common Information Entry (CIE). This
-  /// holds information that is shared among many Frame Description Entries.
-  /// There is at least one CIE in every non-empty .debug_frame section.
-  void EmitCommonInformationEntry(const Function *Personality, unsigned Index);
-
-  /// EmitFrameDescriptionEntry - Emit the Frame Description Entry (FDE) for the
-  /// function.
-  void EmitFrameDescriptionEntry(const FunctionEHFrameInfo &EHFrameInfo);
+  /// EmitCIE - Emit a Common Information Entry (CIE). This holds information
+  /// that is shared among many Frame Description Entries.  There is at least
+  /// one CIE in every non-empty .debug_frame section.
+  void EmitCIE(const Function *Personality, unsigned Index);
+
+  /// EmitFDE - Emit the Frame Description Entry (FDE) for the function.
+  void EmitFDE(const FunctionEHFrameInfo &EHFrameInfo);
 
   /// EmitExceptionTable - Emit landing pads and actions.
   ///





More information about the llvm-commits mailing list